@@ -50,7 +50,6 @@ import fnmatch
 import sys
 import os
 import doctest
-import inspect
 import cStringIO
 from copy import copy
 
@@ -130,7 +129,7 @@ You may get the package by ``pip install webtest``.""")
 
     try:
         from gluon.main import wsgibase
-    except ImportError as e:
+    except ImportError:
         raise ImportError("""
 No module named `gluon`, unable to find `wsgibase`
 
@@ -150,7 +149,7 @@ This should include your `applications` and `gluon` directories.""")
 def new_env(app='init', controller=None):
     try:
         from gluon import shell
-    except ImportError as e:
+    except ImportError:
         raise ImportError("""
 No module named `gluon`, unable to find `shell`
 
@@ -180,7 +179,7 @@ This should include your `applications` and `gluon` directories.""")
 def copy_db(env, db_name='db', db_link='sqlite:memory:'):
     try:
         from gluon.sql import DAL
-    except ImportError as e:
+    except ImportError:
         raise ImportError("""
 No module named `gluon`, unable to find `sql.DAL`
 
@@ -216,6 +215,8 @@ def get_suite(app='init'):
 
     # Unit Testing
     for test_file in test_files:
+        if test_file.find('/'+os.path.basename(__file__)) != -1:
+            continue
         g = copy(globals())
 
         # Execute our test file.
@@ -237,7 +238,7 @@ def get_suite(app='init'):
 
     return suite
 
-def run(path                = '/path/to/web2py',
+def run(path                = None,
         app                 = 'welcome',
         test_key            = 'secret',
         test_options        = {'verbosity': 1},
@@ -302,7 +303,7 @@ def run(path                = '/path/to/web2py',
     global _APP_PATH
     global _TEST_APP_KEY
 
-    if _GLUON:
+    if _GLUON and not path:
         path = os.getcwd()
 
     _PATH           = path
